Prof. Daniel Boćkowski: Polityczne napięcie będzie rosło

Czytaj dalej
Fot. Piotr Hukało

# Prof. Daniel Boćkowski: Polityczne napięcie będzie rosło

Nie atakują nas ludzie krzyczący Allahu Akhbar tylko „nienawidzę PO” czy „nienawidzę PiS” - mówi prof. Daniel Boćkowski z UwB.

W mediach pojawił się wpis, że to co się wydarzyło w Gdańsku - zginął prezydent Paweł Adamowicz - to akt terroru. Tak pan uważa?

Tak, osoba, która dokonała tego ataku, przygotowała się niezwykle starannie. Wybrała jako cel osobę medialną oraz wyjątkowy dla wielu Polaków czas i miejsce. Wyposażyła się w nóż bojowy o długim ostrzu i zadała nim w sposób bezwzględny kilka ciosów, z których w zasadzie niemal każdy był śmiertelny. Uderzyła w chwili uruchomienia na scenie pirotechniki, co dodatkowo dawało pewność, że zrealizuje swój cel. A celem był zarówno prezydent Adamowicz, jak i sama impreza. Temu człowiekowi zależało na jak największym rozgłosie i bez wątpienie rozgłos ten osiągnął.